Module format

Module format 

Format trait and auto-detection.

The StationXmlFormat trait is implemented by each format backend (FDSN, SC3ML). detect_format inspects the root XML element to determine which format a document uses.

Enums

Format
Supported XML formats.

Traits

StationXmlFormat
Trait implemented by each format backend.

Functions

detect_format
Detect the XML format by inspecting the root element name.