pub fn load_sensor_library() -> &'static [SensorEntry]Expand description
Load the built-in sensor library.
Returns a slice of all sensor entries. The library is lazily initialized and cached for the lifetime of the program.
pub fn load_sensor_library() -> &'static [SensorEntry]Load the built-in sensor library.
Returns a slice of all sensor entries. The library is lazily initialized and cached for the lifetime of the program.